@@ -1,14 +1,14 @@
 import asyncio
 from contextlib import asynccontextmanager
-import logging
 import typing
 import weakref
 
 from momotor.shared.exlock import ExLock
 from .base import StateABC
 from ..doc import annotate_docstring
+from ..log import getAsyncLogger
 
-logger = logging.getLogger(__name__)
+logger = getAsyncLogger(__name__)
 
 
 @annotate_docstring(logger=logger)
@@ -38,16 +38,16 @@ class LocalState(StateABC):
         # using async-with causes similar problems, therefor using acquire and release
 
         exlock = await self._get_rwlock(key, True)
-        logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} acquiring {exlock}')
+        await logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} acquiring {exlock}')
 
         await exlock.get(exclusive).acquire()
-        logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} acquired {exlock}')
+        await logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} acquired {exlock}')
 
         try:
             yield
         finally:
             exlock.get(exclusive).release()
-            logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} released {exlock}')
+            await logger.debug(f'state lock {key}{" exclusive" if exclusive else ""} released {exlock}')
 
     async def test_lock(self, key: str, *, exclusive: bool = True) -> bool:
         exlock = await self._get_rwlock(key, False)
